<?php

namespace Litecms\Product\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Product\Http\Requests\ProducstRequest;
use Litecms\Product\Interfaces\ProducstRepositoryInterface;
use Litecms\Product\Models\Producst;

/**
 * Resource controller class for producst.
 */
class ProducstResourceController extends BaseController
{

    /**
     * Initialize producst resource controller.
     *
     * @param type ProducstRepositoryInterface $producst
     *
     * @return null
     */
    public function __construct(ProducstRepositoryInterface $producst)
    {
        parent::__construct();
        $this->repository = $producst;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Product\Repositories\Criteria\ProducstResourceCriteria::class);
    }

    /**
     * Display a list of producst.
     *
     * @return Response
     */
    public function index(ProducstRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Product\Repositories\Presenter\ProducstPresenter::class)
                ->$function();
        }

        $producsts = $this->repository->paginate();

        return $this->response->title(trans('product::producst.names'))
            ->view('product::producst.index', true)
            ->data(compact('producsts'))
            ->output();
    }

    /**
     * Display producst.
     *
     * @param Request $request
     * @param Model   $producst
     *
     * @return Response
     */
    public function show(ProducstRequest $request, Producst $producst)
    {

        if ($producst->exists) {
            $view = 'product::producst.show';
        } else {
            $view = 'product::producst.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('product::producst.name'))
            ->data(compact('producst'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new producst.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ProducstRequest $request)
    {

        $producst = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('product::producst.name')) 
            ->view('product::producst.create', true) 
            ->data(compact('producst'))
            ->output();
    }

    /**
     * Create new producst.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ProducstRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $producst                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('product::producst.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('product/producst/' . $producst->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/product/producst'))
                ->redirect();
        }

    }

    /**
     * Show producst for editing.
     *
     * @param Request $request
     * @param Model   $producst
     *
     * @return Response
     */
    public function edit(ProducstRequest $request, Producst $producst)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('product::producst.name'))
            ->view('product::producst.edit', true)
            ->data(compact('producst'))
            ->output();
    }

    /**
     * Update the producst.
     *
     * @param Request $request
     * @param Model   $producst
     *
     * @return Response
     */
    public function update(ProducstRequest $request, Producst $producst)
    {
        try {
            $attributes = $request->all();

            $producst->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('product::producst.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('product/producst/' . $producst->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('product/producst/' . $producst->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the producst.
     *
     * @param Model   $producst
     *
     * @return Response
     */
    public function destroy(ProducstRequest $request, Producst $producst)
    {
        try {

            $producst->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('product::producst.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('product/producst/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('product/producst/' . $producst->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple producst.
     *
     * @param Model   $producst
     *
     * @return Response
     */
    public function delete(ProducstRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('product::producst.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('product/producst'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/product/producst'))
                ->redirect();
        }

    }

    /**
     * Restore deleted producsts.
     *
     * @param Model   $producst
     *
     * @return Response
     */
    public function restore(ProducstRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('product::producst.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/product/producst'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/product/producst/'))
                ->redirect();
        }

    }

}
